@@ -5,9 +5,24 @@ use warnings;
 use parent 'Alien::Base';
 
 # ABSTRACT: Install hunspell
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
+sub dynamic_libs
+{
+  my($self) = @_;
+  $self->install_type ne 'system'
+    ? $self->SUPER::dynamic_libs
+    : do {
+      require FFI::CheckLib;
+      FFI::CheckLib::find_lib(
+        lib => '*',
+        verify => sub { $_[0] =~ /hunspell/ },
+        symbol => 'Hunspell_create',
+      );
+    };
+}
+
 1;
 
 __END__
@@ -22,7 +37,7 @@ Alien::Hunspell - Install hunspell
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
